# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class TransferRetry(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 status=None,
                 started_at=None,
                 finished_at=None,
                 error_at=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, Status, datetime, datetime, datetime) -> None
        super(TransferRetry, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._status = None
        self._started_at = None
        self._finished_at = None
        self._error_at = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if started_at is not None:
            self.started_at = started_at
        if finished_at is not None:
            self.finished_at = finished_at
        if error_at is not None:
            self.error_at = error_at

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(TransferRetry, self), 'openapi_types'):
            types = getattr(super(TransferRetry, self), 'openapi_types')

        types.update({
            'status': 'Status',
            'started_at': 'datetime',
            'finished_at': 'datetime',
            'error_at': 'datetime'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(TransferRetry, self), 'attribute_map'):
            attributes = getattr(super(TransferRetry, self), 'attribute_map')

        attributes.update({
            'status': 'status',
            'started_at': 'startedAt',
            'finished_at': 'finishedAt',
            'error_at': 'errorAt'
        })
        return attributes

    @property
    def status(self):
        # type: () -> Status
        """Gets the status of this TransferRetry.

        The current status of the transfer-retry.

        :return: The status of this TransferRetry.
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (Status) -> None
        """Sets the status of this TransferRetry.

        The current status of the transfer-retry.

        :param status: The status of this TransferRetry.
        :type: Status
        """

        if status is not None:
            if not isinstance(status, Status):
                raise TypeError("Invalid type for `status`, type has to be `Status`")

        self._status = status

    @property
    def started_at(self):
        # type: () -> datetime
        """Gets the started_at of this TransferRetry.

        Timestamp when the transfer-retry was started, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The started_at of this TransferRetry.
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        # type: (datetime) -> None
        """Sets the started_at of this TransferRetry.

        Timestamp when the transfer-retry was started, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param started_at: The started_at of this TransferRetry.
        :type: datetime
        """

        if started_at is not None:
            if not isinstance(started_at, datetime):
                raise TypeError("Invalid type for `started_at`, type has to be `datetime`")

        self._started_at = started_at

    @property
    def finished_at(self):
        # type: () -> datetime
        """Gets the finished_at of this TransferRetry.

        Timestamp when the transfer-retry status changed to 'FINISHED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The finished_at of this TransferRetry.
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        # type: (datetime) -> None
        """Sets the finished_at of this TransferRetry.

        Timestamp when the transfer-retry status changed to 'FINISHED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param finished_at: The finished_at of this TransferRetry.
        :type: datetime
        """

        if finished_at is not None:
            if not isinstance(finished_at, datetime):
                raise TypeError("Invalid type for `finished_at`, type has to be `datetime`")

        self._finished_at = finished_at

    @property
    def error_at(self):
        # type: () -> datetime
        """Gets the error_at of this TransferRetry.

        Timestamp when the transfer-retry status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :return: The error_at of this TransferRetry.
        :rtype: datetime
        """
        return self._error_at

    @error_at.setter
    def error_at(self, error_at):
        # type: (datetime) -> None
        """Sets the error_at of this TransferRetry.

        Timestamp when the transfer-retry status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 

        :param error_at: The error_at of this TransferRetry.
        :type: datetime
        """

        if error_at is not None:
            if not isinstance(error_at, datetime):
                raise TypeError("Invalid type for `error_at`, type has to be `datetime`")

        self._error_at = error_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(TransferRetry, self), "to_dict"):
            result = super(TransferRetry, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransferRetry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.streams_domain_restriction_create_request import StreamsDomainRestrictionCreateRequest
from bitmovin_api_sdk.models.streams_domain_restriction_response import StreamsDomainRestrictionResponse
from bitmovin_api_sdk.models.streams_domain_restriction_update_request import StreamsDomainRestrictionUpdateRequest
from bitmovin_api_sdk.streams.config.domain_restriction.streams_domain_restriction_response_list_query_params import StreamsDomainRestrictionResponseListQueryParams


class DomainRestrictionApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DomainRestrictionApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, streams_domain_restriction_create_request, **kwargs):
        # type: (StreamsDomainRestrictionCreateRequest, dict) -> StreamsDomainRestrictionResponse
        """Create new streams domain restriction

        :param streams_domain_restriction_create_request: Create a new streams domain restriction
        :type streams_domain_restriction_create_request: StreamsDomainRestrictionCreateRequest, required
        :return: Created streams domain restriction
        :rtype: StreamsDomainRestrictionResponse
        """

        return self.api_client.post(
            '/streams/config/domain-restriction/',
            streams_domain_restriction_create_request,
            type=StreamsDomainRestrictionResponse,
            **kwargs
        )

    def delete(self, domain_restriction_id, **kwargs):
        # type: (string_types, dict) -> None
        """Delete streams domain restriction by id

        :param domain_restriction_id: Id of the streams domain restriction.
        :type domain_restriction_id: string_types, required
        """

        self.api_client.delete(
            '/streams/config/domain-restriction/{domain_restriction_id}',
            path_params={'domain_restriction_id': domain_restriction_id},
            **kwargs
        )

    def get(self, domain_restriction_id, **kwargs):
        # type: (string_types, dict) -> StreamsDomainRestrictionResponse
        """Get streams domain restriction config by id

        :param domain_restriction_id: Id of the streams domain restriction.
        :type domain_restriction_id: string_types, required
        :return:
        :rtype: StreamsDomainRestrictionResponse
        """

        return self.api_client.get(
            '/streams/config/domain-restriction/{domain_restriction_id}',
            path_params={'domain_restriction_id': domain_restriction_id},
            type=StreamsDomainRestrictionResponse,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (StreamsDomainRestrictionResponseListQueryParams, dict) -> StreamsDomainRestrictionResponse
        """Get paginated list of domain restriction configurations

        :param query_params: Query parameters
        :type query_params: StreamsDomainRestrictionResponseListQueryParams
        :return: List of all streams domain restriction configs
        :rtype: StreamsDomainRestrictionResponse
        """

        return self.api_client.get(
            '/streams/config/domain-restriction/',
            query_params=query_params,
            pagination_response=True,
            type=StreamsDomainRestrictionResponse,
            **kwargs
        )

    def patch_streams_domain_restriction(self, domain_restriction_id, streams_domain_restriction_update_request, **kwargs):
        # type: (string_types, StreamsDomainRestrictionUpdateRequest, dict) -> StreamsDomainRestrictionResponse
        """Partially update streams domain restriction by id

        :param domain_restriction_id: Id of the streams domain restriction.
        :type domain_restriction_id: string_types, required
        :param streams_domain_restriction_update_request: The updated streams domain restriction object.
        :type streams_domain_restriction_update_request: StreamsDomainRestrictionUpdateRequest, required
        :return:
        :rtype: StreamsDomainRestrictionResponse
        """

        return self.api_client.patch(
            '/streams/config/domain-restriction/{domain_restriction_id}',
            streams_domain_restriction_update_request,
            path_params={'domain_restriction_id': domain_restriction_id},
            type=StreamsDomainRestrictionResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.filters.azure_speech_to_captions.azure_speech_to_captions_api import AzureSpeechToCaptionsApi
from bitmovin_api_sdk.encoding.filters.azure_speech_to_captions.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.azure_speech_to_captions.azure_speech_to_captions_filter_list_query_params import AzureSpeechToCaptionsFilterListQueryParams



from bitmovin_api_sdk.encoding.encodings.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.encodings.live.reset_live_manifest_timeshift.reset_live_manifest_timeshift_api import ResetLiveManifestTimeshiftApi
from bitmovin_api_sdk.encoding.encodings.live.hd.hd_api import HdApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_api import InsertableContentApi
from bitmovin_api_sdk.encoding.encodings.live.scte35_cue.scte35_cue_api import Scte35CueApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cenc_fair_play import CencFairPlay
from bitmovin_api_sdk.models.cenc_marlin import CencMarlin
from bitmovin_api_sdk.models.cenc_play_ready import CencPlayReady
from bitmovin_api_sdk.models.cenc_widevine import CencWidevine
from bitmovin_api_sdk.models.drm import Drm
from bitmovin_api_sdk.models.encryption_mode import EncryptionMode
from bitmovin_api_sdk.models.iv_size import IvSize
import pprint
import six


class CencDrm(Drm):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 outputs=None,
                 key=None,
                 kid=None,
                 encryption_mode=None,
                 iv_size=None,
                 enable_piff_compatibility=None,
                 widevine=None,
                 play_ready=None,
                 marlin=None,
                 fair_play=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[EncodingOutput], string_types, string_types, EncryptionMode, IvSize, bool, CencWidevine, CencPlayReady, CencMarlin, CencFairPlay) -> None
        super(CencDrm, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, outputs=outputs)

        self._key = None
        self._kid = None
        self._encryption_mode = None
        self._iv_size = None
        self._enable_piff_compatibility = None
        self._widevine = None
        self._play_ready = None
        self._marlin = None
        self._fair_play = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if kid is not None:
            self.kid = kid
        if encryption_mode is not None:
            self.encryption_mode = encryption_mode
        if iv_size is not None:
            self.iv_size = iv_size
        if enable_piff_compatibility is not None:
            self.enable_piff_compatibility = enable_piff_compatibility
        if widevine is not None:
            self.widevine = widevine
        if play_ready is not None:
            self.play_ready = play_ready
        if marlin is not None:
            self.marlin = marlin
        if fair_play is not None:
            self.fair_play = fair_play

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(CencDrm, self), 'openapi_types'):
            types = getattr(super(CencDrm, self), 'openapi_types')

        types.update({
            'key': 'string_types',
            'kid': 'string_types',
            'encryption_mode': 'EncryptionMode',
            'iv_size': 'IvSize',
            'enable_piff_compatibility': 'bool',
            'widevine': 'CencWidevine',
            'play_ready': 'CencPlayReady',
            'marlin': 'CencMarlin',
            'fair_play': 'CencFairPlay'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(CencDrm, self), 'attribute_map'):
            attributes = getattr(super(CencDrm, self), 'attribute_map')

        attributes.update({
            'key': 'key',
            'kid': 'kid',
            'encryption_mode': 'encryptionMode',
            'iv_size': 'ivSize',
            'enable_piff_compatibility': 'enablePiffCompatibility',
            'widevine': 'widevine',
            'play_ready': 'playReady',
            'marlin': 'marlin',
            'fair_play': 'fairPlay'
        })
        return attributes

    @property
    def key(self):
        # type: () -> string_types
        """Gets the key of this CencDrm.

        16 byte encryption key, 32 hexadecimal characters (required)

        :return: The key of this CencDrm.
        :rtype: string_types
        """
        return self._key

    @key.setter
    def key(self, key):
        # type: (string_types) -> None
        """Sets the key of this CencDrm.

        16 byte encryption key, 32 hexadecimal characters (required)

        :param key: The key of this CencDrm.
        :type: string_types
        """

        if key is not None:
            if not isinstance(key, string_types):
                raise TypeError("Invalid type for `key`, type has to be `string_types`")

        self._key = key

    @property
    def kid(self):
        # type: () -> string_types
        """Gets the kid of this CencDrm.

        16 byte encryption key id. Required for any other DRM but FairPlay

        :return: The kid of this CencDrm.
        :rtype: string_types
        """
        return self._kid

    @kid.setter
    def kid(self, kid):
        # type: (string_types) -> None
        """Sets the kid of this CencDrm.

        16 byte encryption key id. Required for any other DRM but FairPlay

        :param kid: The kid of this CencDrm.
        :type: string_types
        """

        if kid is not None:
            if not isinstance(kid, string_types):
                raise TypeError("Invalid type for `kid`, type has to be `string_types`")

        self._kid = kid

    @property
    def encryption_mode(self):
        # type: () -> EncryptionMode
        """Gets the encryption_mode of this CencDrm.

        The encryption method to use. Default is `CTR` (required)

        :return: The encryption_mode of this CencDrm.
        :rtype: EncryptionMode
        """
        return self._encryption_mode

    @encryption_mode.setter
    def encryption_mode(self, encryption_mode):
        # type: (EncryptionMode) -> None
        """Sets the encryption_mode of this CencDrm.

        The encryption method to use. Default is `CTR` (required)

        :param encryption_mode: The encryption_mode of this CencDrm.
        :type: EncryptionMode
        """

        if encryption_mode is not None:
            if not isinstance(encryption_mode, EncryptionMode):
                raise TypeError("Invalid type for `encryption_mode`, type has to be `EncryptionMode`")

        self._encryption_mode = encryption_mode

    @property
    def iv_size(self):
        # type: () -> IvSize
        """Gets the iv_size of this CencDrm.

        Size of the initialization vector

        :return: The iv_size of this CencDrm.
        :rtype: IvSize
        """
        return self._iv_size

    @iv_size.setter
    def iv_size(self, iv_size):
        # type: (IvSize) -> None
        """Sets the iv_size of this CencDrm.

        Size of the initialization vector

        :param iv_size: The iv_size of this CencDrm.
        :type: IvSize
        """

        if iv_size is not None:
            if not isinstance(iv_size, IvSize):
                raise TypeError("Invalid type for `iv_size`, type has to be `IvSize`")

        self._iv_size = iv_size

    @property
    def enable_piff_compatibility(self):
        # type: () -> bool
        """Gets the enable_piff_compatibility of this CencDrm.

        Enables compatibility with the Protected Interoperable File Format (PIFF) specification

        :return: The enable_piff_compatibility of this CencDrm.
        :rtype: bool
        """
        return self._enable_piff_compatibility

    @enable_piff_compatibility.setter
    def enable_piff_compatibility(self, enable_piff_compatibility):
        # type: (bool) -> None
        """Sets the enable_piff_compatibility of this CencDrm.

        Enables compatibility with the Protected Interoperable File Format (PIFF) specification

        :param enable_piff_compatibility: The enable_piff_compatibility of this CencDrm.
        :type: bool
        """

        if enable_piff_compatibility is not None:
            if not isinstance(enable_piff_compatibility, bool):
                raise TypeError("Invalid type for `enable_piff_compatibility`, type has to be `bool`")

        self._enable_piff_compatibility = enable_piff_compatibility

    @property
    def widevine(self):
        # type: () -> CencWidevine
        """Gets the widevine of this CencDrm.

        Configuration for Widevine DRM

        :return: The widevine of this CencDrm.
        :rtype: CencWidevine
        """
        return self._widevine

    @widevine.setter
    def widevine(self, widevine):
        # type: (CencWidevine) -> None
        """Sets the widevine of this CencDrm.

        Configuration for Widevine DRM

        :param widevine: The widevine of this CencDrm.
        :type: CencWidevine
        """

        if widevine is not None:
            if not isinstance(widevine, CencWidevine):
                raise TypeError("Invalid type for `widevine`, type has to be `CencWidevine`")

        self._widevine = widevine

    @property
    def play_ready(self):
        # type: () -> CencPlayReady
        """Gets the play_ready of this CencDrm.

        Configuration for PlayReady DRM

        :return: The play_ready of this CencDrm.
        :rtype: CencPlayReady
        """
        return self._play_ready

    @play_ready.setter
    def play_ready(self, play_ready):
        # type: (CencPlayReady) -> None
        """Sets the play_ready of this CencDrm.

        Configuration for PlayReady DRM

        :param play_ready: The play_ready of this CencDrm.
        :type: CencPlayReady
        """

        if play_ready is not None:
            if not isinstance(play_ready, CencPlayReady):
                raise TypeError("Invalid type for `play_ready`, type has to be `CencPlayReady`")

        self._play_ready = play_ready

    @property
    def marlin(self):
        # type: () -> CencMarlin
        """Gets the marlin of this CencDrm.

        Configuration for Marlin DRM

        :return: The marlin of this CencDrm.
        :rtype: CencMarlin
        """
        return self._marlin

    @marlin.setter
    def marlin(self, marlin):
        # type: (CencMarlin) -> None
        """Sets the marlin of this CencDrm.

        Configuration for Marlin DRM

        :param marlin: The marlin of this CencDrm.
        :type: CencMarlin
        """

        if marlin is not None:
            if not isinstance(marlin, CencMarlin):
                raise TypeError("Invalid type for `marlin`, type has to be `CencMarlin`")

        self._marlin = marlin

    @property
    def fair_play(self):
        # type: () -> CencFairPlay
        """Gets the fair_play of this CencDrm.

        Configuration for FairPlay DRM

        :return: The fair_play of this CencDrm.
        :rtype: CencFairPlay
        """
        return self._fair_play

    @fair_play.setter
    def fair_play(self, fair_play):
        # type: (CencFairPlay) -> None
        """Sets the fair_play of this CencDrm.

        Configuration for FairPlay DRM

        :param fair_play: The fair_play of this CencDrm.
        :type: CencFairPlay
        """

        if fair_play is not None:
            if not isinstance(fair_play, CencFairPlay):
                raise TypeError("Invalid type for `fair_play`, type has to be `CencFairPlay`")

        self._fair_play = fair_play

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(CencDrm, self), "to_dict"):
            result = super(CencDrm, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CencDrm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AvailabilityStartTimeMode(Enum):
    ON_FIRST_SEGMENT = "ON_FIRST_SEGMENT"
    ON_STREAM_INGEST = "ON_STREAM_INGEST"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.cloud_region import CloudRegion
from bitmovin_api_sdk.models.encoding import Encoding
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.reprioritize_encoding_request import ReprioritizeEncodingRequest
from bitmovin_api_sdk.models.reschedule_encoding_request import RescheduleEncodingRequest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.start_encoding_request import StartEncodingRequest
from bitmovin_api_sdk.models.task import Task
from bitmovin_api_sdk.encoding.encodings.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.encodings.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.encodings.input_streams.input_streams_api import InputStreamsApi
from bitmovin_api_sdk.encoding.encodings.muxings.muxings_api import MuxingsApi
from bitmovin_api_sdk.encoding.encodings.transfer_retries.transfer_retries_api import TransferRetriesApi
from bitmovin_api_sdk.encoding.encodings.output_paths.output_paths_api import OutputPathsApi
from bitmovin_api_sdk.encoding.encodings.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.sidecars.sidecars_api import SidecarsApi
from bitmovin_api_sdk.encoding.encodings.keyframes.keyframes_api import KeyframesApi
from bitmovin_api_sdk.encoding.encodings.encoding_list_query_params import EncodingListQueryParams


class EncodingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.live = LiveApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.streams = StreamsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.input_streams = InputStreamsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.muxings = MuxingsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.transfer_retries = TransferRetriesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.output_paths = OutputPathsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.captions = CaptionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sidecars = SidecarsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.keyframes = KeyframesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding, **kwargs):
        # type: (Encoding, dict) -> Encoding
        """Create Encoding

        :param encoding: The Encoding to be created
        :type encoding: Encoding, required
        :return: Encoding
        :rtype: Encoding
        """

        return self.api_client.post(
            '/encoding/encodings',
            encoding,
            type=Encoding,
            **kwargs
        )

    def delete(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}',
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> Encoding
        """Encoding Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: Encoding
        :rtype: Encoding
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}',
            path_params={'encoding_id': encoding_id},
            type=Encoding,
            **kwargs
        )

    def get_start_request(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> StartEncodingRequest
        """Encoding Start Details

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return: Service specific result
        :rtype: StartEncodingRequest
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/start',
            path_params={'encoding_id': encoding_id},
            type=StartEncodingRequest,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (EncodingListQueryParams, dict) -> Encoding
        """List all Encodings

        :param query_params: Query parameters
        :type query_params: EncodingListQueryParams
        :return: List of encodings
        :rtype: Encoding
        """

        return self.api_client.get(
            '/encoding/encodings',
            query_params=query_params,
            pagination_response=True,
            type=Encoding,
            **kwargs
        )

    def reprioritize(self, encoding_id, reprioritize_encoding_request, **kwargs):
        # type: (string_types, ReprioritizeEncodingRequest, dict) -> BitmovinResponse
        """Reprioritize Encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param reprioritize_encoding_request: Reprioritization options
        :type reprioritize_encoding_request: ReprioritizeEncodingRequest, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/reprioritize',
            reprioritize_encoding_request,
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def reschedule(self, encoding_id, reschedule_encoding_request, **kwargs):
        # type: (string_types, RescheduleEncodingRequest, dict) -> BitmovinResponse
        """Reschedule Encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param reschedule_encoding_request: Rescheduling options
        :type reschedule_encoding_request: RescheduleEncodingRequest, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/reschedule',
            reschedule_encoding_request,
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def start(self, encoding_id, start_encoding_request=None, **kwargs):
        # type: (string_types, StartEncodingRequest, dict) -> BitmovinResponse
        """Start VoD Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param start_encoding_request: Encoding Startup Options
        :type start_encoding_request: StartEncodingRequest
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/start',
            start_encoding_request,
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def status(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> Task
        """Encoding Status

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return: Status of encoding
        :rtype: Task
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/status',
            path_params={'encoding_id': encoding_id},
            type=Task,
            **kwargs
        )

    def stop(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/stop',
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class ResetLiveManifestTimeShift(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 residual_period_in_seconds=None,
                 manifest_ids=None):
        # type: (string_types, float, list[string_types]) -> None
        super(ResetLiveManifestTimeShift, self).__init__(id_=id_)

        self._residual_period_in_seconds = None
        self._manifest_ids = list()
        self.discriminator = None

        if residual_period_in_seconds is not None:
            self.residual_period_in_seconds = residual_period_in_seconds
        if manifest_ids is not None:
            self.manifest_ids = manifest_ids

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ResetLiveManifestTimeShift, self), 'openapi_types'):
            types = getattr(super(ResetLiveManifestTimeShift, self), 'openapi_types')

        types.update({
            'residual_period_in_seconds': 'float',
            'manifest_ids': 'list[string_types]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ResetLiveManifestTimeShift, self), 'attribute_map'):
            attributes = getattr(super(ResetLiveManifestTimeShift, self), 'attribute_map')

        attributes.update({
            'residual_period_in_seconds': 'residualPeriodInSeconds',
            'manifest_ids': 'manifestIds'
        })
        return attributes

    @property
    def residual_period_in_seconds(self):
        # type: () -> float
        """Gets the residual_period_in_seconds of this ResetLiveManifestTimeShift.

        Determines how many seconds will be left in the manifest after segments are removed. If this is not set, all but one segment will be removed. 

        :return: The residual_period_in_seconds of this ResetLiveManifestTimeShift.
        :rtype: float
        """
        return self._residual_period_in_seconds

    @residual_period_in_seconds.setter
    def residual_period_in_seconds(self, residual_period_in_seconds):
        # type: (float) -> None
        """Sets the residual_period_in_seconds of this ResetLiveManifestTimeShift.

        Determines how many seconds will be left in the manifest after segments are removed. If this is not set, all but one segment will be removed. 

        :param residual_period_in_seconds: The residual_period_in_seconds of this ResetLiveManifestTimeShift.
        :type: float
        """

        if residual_period_in_seconds is not None:
            if not isinstance(residual_period_in_seconds, (float, int)):
                raise TypeError("Invalid type for `residual_period_in_seconds`, type has to be `float`")

        self._residual_period_in_seconds = residual_period_in_seconds

    @property
    def manifest_ids(self):
        # type: () -> list[string_types]
        """Gets the manifest_ids of this ResetLiveManifestTimeShift.

        The ids of the manifests to update. If this property is not set, all manifests tied to the encoding are updated.

        :return: The manifest_ids of this ResetLiveManifestTimeShift.
        :rtype: list[string_types]
        """
        return self._manifest_ids

    @manifest_ids.setter
    def manifest_ids(self, manifest_ids):
        # type: (list) -> None
        """Sets the manifest_ids of this ResetLiveManifestTimeShift.

        The ids of the manifests to update. If this property is not set, all manifests tied to the encoding are updated.

        :param manifest_ids: The manifest_ids of this ResetLiveManifestTimeShift.
        :type: list[string_types]
        """

        if manifest_ids is not None:
            if not isinstance(manifest_ids, list):
                raise TypeError("Invalid type for `manifest_ids`, type has to be `list[string_types]`")

        self._manifest_ids = manifest_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ResetLiveManifestTimeShift, self), "to_dict"):
            result = super(ResetLiveManifestTimeShift, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetLiveManifestTimeShift):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class BroadcastTsSubtitleInputStreamConfiguration(object):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 packet_identifier=None,
                 rate=None):
        # type: (string_types, int, int) -> None

        self._stream_id = None
        self._packet_identifier = None
        self._rate = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if packet_identifier is not None:
            self.packet_identifier = packet_identifier
        if rate is not None:
            self.rate = rate

    @property
    def openapi_types(self):
        types = {
            'stream_id': 'string_types',
            'packet_identifier': 'int',
            'rate': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_id': 'streamId',
            'packet_identifier': 'packetIdentifier',
            'rate': 'rate'
        }
        return attributes

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this BroadcastTsSubtitleInputStreamConfiguration.

        The UUID of the subtitle stream to which this configuration belongs to. This has to be an ID of an subtitle stream that has been added to the current muxing. 

        :return: The stream_id of this BroadcastTsSubtitleInputStreamConfiguration.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this BroadcastTsSubtitleInputStreamConfiguration.

        The UUID of the subtitle stream to which this configuration belongs to. This has to be an ID of an subtitle stream that has been added to the current muxing. 

        :param stream_id: The stream_id of this BroadcastTsSubtitleInputStreamConfiguration.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def packet_identifier(self):
        # type: () -> int
        """Gets the packet_identifier of this BroadcastTsSubtitleInputStreamConfiguration.

        An integer value. Packet Identifier (PID) for this stream.

        :return: The packet_identifier of this BroadcastTsSubtitleInputStreamConfiguration.
        :rtype: int
        """
        return self._packet_identifier

    @packet_identifier.setter
    def packet_identifier(self, packet_identifier):
        # type: (int) -> None
        """Sets the packet_identifier of this BroadcastTsSubtitleInputStreamConfiguration.

        An integer value. Packet Identifier (PID) for this stream.

        :param packet_identifier: The packet_identifier of this BroadcastTsSubtitleInputStreamConfiguration.
        :type: int
        """

        if packet_identifier is not None:
            if packet_identifier is not None and packet_identifier > 8190:
                raise ValueError("Invalid value for `packet_identifier`, must be a value less than or equal to `8190`")
            if packet_identifier is not None and packet_identifier < 16:
                raise ValueError("Invalid value for `packet_identifier`, must be a value greater than or equal to `16`")
            if not isinstance(packet_identifier, int):
                raise TypeError("Invalid type for `packet_identifier`, type has to be `int`")

        self._packet_identifier = packet_identifier

    @property
    def rate(self):
        # type: () -> int
        """Gets the rate of this BroadcastTsSubtitleInputStreamConfiguration.

        The rate parameter determines the maximum rate in bits per second that should be used for the subtitle stream. The valid range is `100` to `60 000 000` bps or `0`. If the value is set to 0, we will examine the first 100 packets of subtitle packet data and use the highest rate that was computed. If the value is set too low, not enough to accommodate the subtitle bit-rate, then some PES packets corresponding to DVB subtitle stream will be dropped. This parameter is optional and the default value is 0. 

        :return: The rate of this BroadcastTsSubtitleInputStreamConfiguration.
        :rtype: int
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (int) -> None
        """Sets the rate of this BroadcastTsSubtitleInputStreamConfiguration.

        The rate parameter determines the maximum rate in bits per second that should be used for the subtitle stream. The valid range is `100` to `60 000 000` bps or `0`. If the value is set to 0, we will examine the first 100 packets of subtitle packet data and use the highest rate that was computed. If the value is set too low, not enough to accommodate the subtitle bit-rate, then some PES packets corresponding to DVB subtitle stream will be dropped. This parameter is optional and the default value is 0. 

        :param rate: The rate of this BroadcastTsSubtitleInputStreamConfiguration.
        :type: int
        """

        if rate is not None:
            if rate is not None and rate > 60000000:
                raise ValueError("Invalid value for `rate`, must be a value less than or equal to `60000000`")
            if rate is not None and rate < 0:
                raise ValueError("Invalid value for `rate`, must be a value greater than or equal to `0`")
            if not isinstance(rate, int):
                raise TypeError("Invalid type for `rate`, type has to be `int`")

        self._rate = rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BroadcastTsSubtitleInputStreamConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class NexGuardWatermarkingStrength(Enum):
    LIGHTEST = "LIGHTEST"
    LIGHTER = "LIGHTER"
    DEFAULT = "DEFAULT"
    STRONGER = "STRONGER"
    STRONGEST = "STRONGEST"



from bitmovin_api_sdk.encoding.filters.audio_volume.audio_volume_api import AudioVolumeApi
from bitmovin_api_sdk.encoding.filters.audio_volume.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.audio_volume.audio_volume_filter_list_query_params import AudioVolumeFilterListQueryParams



from bitmovin_api_sdk.encoding.manifests.dash.periods.periods_api import PeriodsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.custom_xml_elements.custom_xml_elements_api import CustomXmlElementsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.adaptationsets_api import AdaptationsetsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.period_list_query_params import PeriodListQueryParams



from datetime import datetime
from requests import RequestException, Request, Response
from json import dumps
from bitmovin_api_sdk.common.bitmovin_json_decoder import BitmovinJsonDecoder
from bitmovin_api_sdk.models import ResponseErrorData, Message, Link


class BitmovinError(Exception):
    def __init__(self,
                 e,
                 http_request_method=None,
                 http_request_url=None,
                 http_request_payload=None):
        # type: (Exception) -> None

        super(BitmovinError, self).__init__()

        self.http_request_method = http_request_method
        self.http_request_url = http_request_url
        self.http_request_payload = http_request_payload
        self._request = None
        self._response = None
        self.cause = e
        self.message = None
        self.http_status_code = None
        self.short_message = None
        self.developer_message = None
        self.error_code = None
        self.details = []
        self.links = []

        if e is not None:
            self.short_message = e.__str__()

        if isinstance(e, RequestException):
            self._response = e.response  # type: Response
            self._request = e.request  # type: Request

            if self._response is not None:
                self.http_status_code = self._response.status_code
                self.short_message = self._response.reason
                try:
                    body = self._response.json()
                    error = self._map_response_to_error(response=body)
                    if isinstance(error, ResponseErrorData):
                        self.error_code = error.code
                        self.short_message = error.message
                        self.developer_message = error.developer_message
                        self.details = error.details
                        self.links = error.links
                except ValueError:
                    pass

        self.message = self._create_error_message()

    def __str__(self):
        return self.message

    def _create_error_message(self):
        message = ''
        if self.short_message is not None:
            message += self.short_message
        if self.developer_message is not None:
            message += '\ndeveloperMessage: {}'.format(self.developer_message)
        if self.error_code is not None:
            message += '\nerrorCode: {}'.format(self.error_code)
        if isinstance(self.details, list) and len(self.details) > 0:
            message += '\ndetails:'
            for detail in self.details:
                if not isinstance(detail, Message):
                    continue
                if detail.id is not None:
                    message += '\n  - id: {}'.format(detail.id)
                if isinstance(detail.date, datetime):
                    message += '\n    date: {}'.format(detail.date.isoformat())
                if detail.type is not None:
                    message += '\n    type: {}'.format(detail.type)
                if detail.text is not None:
                    message += '\n    text: {}'.format(detail.text)
                if detail.field is not None:
                    message += '\n    field: {}'.format(detail.field)
        if isinstance(self.links, list) and len(self.links) > 0:
            message += '\nlinks:'
            for link in self.links:
                if not isinstance(link, Link):
                    continue
                message += '\n  {}: {}'.format(link.title, link.href)
        if self._request is not None:
            message += '\nrequest:'
            message += '\n  method: {}'.format(self._request.method)
            message += '\n  url: {}'.format(self._request.url)
            if self._request.body is not None:
                message += '\n  body: {}'.format(self._request.body)
        elif self.http_request_method is not None:
            message += '\nrequest:'
            message += '\n  method: {}'.format(self.http_request_method)
            message += '\n  url: {}'.format(self.http_request_url)
            if self.http_request_payload is not None:
                message += '\n  body: {}'.format(dumps(self.http_request_payload, sort_keys=True))
        if self._response is not None:
            message += '\nresponse:'
            message += '\n  httpStatusCode: {}'.format(self._response.status_code)
            if self._response.text:
                message += '\n  body: {}'.format(self._response.text)
        return message

    @staticmethod
    def _map_response_to_error(response):
        if 'status' in response and response['status'] == 'ERROR':
            if 'data' in response:
                return BitmovinJsonDecoder.map_dict_to_model(response['data'], ResponseErrorData)
        return response



from bitmovin_api_sdk.encoding.simple.jobs.vod.vod_api import VodApi
from bitmovin_api_sdk.encoding.simple.jobs.vod.simple_encoding_vod_job_response_list_query_params import SimpleEncodingVodJobResponseListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
import pprint
import six


class SimpleEncodingVodJobS3RoleBasedCredentials(SimpleEncodingVodJobCredentials):
    @poscheck_model
    def __init__(self,
                 role_arn=None,
                 use_external_id=None):
        # type: (string_types, bool) -> None
        super(SimpleEncodingVodJobS3RoleBasedCredentials, self).__init__()

        self._role_arn = None
        self._use_external_id = None
        self.discriminator = None

        if role_arn is not None:
            self.role_arn = role_arn
        if use_external_id is not None:
            self.use_external_id = use_external_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SimpleEncodingVodJobS3RoleBasedCredentials, self), 'openapi_types'):
            types = getattr(super(SimpleEncodingVodJobS3RoleBasedCredentials, self), 'openapi_types')

        types.update({
            'role_arn': 'string_types',
            'use_external_id': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SimpleEncodingVodJobS3RoleBasedCredentials, self), 'attribute_map'):
            attributes = getattr(super(SimpleEncodingVodJobS3RoleBasedCredentials, self), 'attribute_map')

        attributes.update({
            'role_arn': 'roleArn',
            'use_external_id': 'useExternalId'
        })
        return attributes

    @property
    def role_arn(self):
        # type: () -> string_types
        """Gets the role_arn of this SimpleEncodingVodJobS3RoleBasedCredentials.

        Amazon ARN of the IAM Role (Identity and Access Management Role) that will be assumed for S3 access. More details can be found [here](https://bitmovin.com/docs/encoding/api-reference/sections/inputs#/Encoding/PostEncodingInputsS3RoleBased) (required)

        :return: The role_arn of this SimpleEncodingVodJobS3RoleBasedCredentials.
        :rtype: string_types
        """
        return self._role_arn

    @role_arn.setter
    def role_arn(self, role_arn):
        # type: (string_types) -> None
        """Sets the role_arn of this SimpleEncodingVodJobS3RoleBasedCredentials.

        Amazon ARN of the IAM Role (Identity and Access Management Role) that will be assumed for S3 access. More details can be found [here](https://bitmovin.com/docs/encoding/api-reference/sections/inputs#/Encoding/PostEncodingInputsS3RoleBased) (required)

        :param role_arn: The role_arn of this SimpleEncodingVodJobS3RoleBasedCredentials.
        :type: string_types
        """

        if role_arn is not None:
            if not isinstance(role_arn, string_types):
                raise TypeError("Invalid type for `role_arn`, type has to be `string_types`")

        self._role_arn = role_arn

    @property
    def use_external_id(self):
        # type: () -> bool
        """Gets the use_external_id of this SimpleEncodingVodJobS3RoleBasedCredentials.

        Defines if the organization ID has to be used as externalId when assuming the role. More details can be found [here](https://bitmovin.com/docs/encoding/api-reference/sections/inputs#/Encoding/PostEncodingInputsS3RoleBased)

        :return: The use_external_id of this SimpleEncodingVodJobS3RoleBasedCredentials.
        :rtype: bool
        """
        return self._use_external_id

    @use_external_id.setter
    def use_external_id(self, use_external_id):
        # type: (bool) -> None
        """Sets the use_external_id of this SimpleEncodingVodJobS3RoleBasedCredentials.

        Defines if the organization ID has to be used as externalId when assuming the role. More details can be found [here](https://bitmovin.com/docs/encoding/api-reference/sections/inputs#/Encoding/PostEncodingInputsS3RoleBased)

        :param use_external_id: The use_external_id of this SimpleEncodingVodJobS3RoleBasedCredentials.
        :type: bool
        """

        if use_external_id is not None:
            if not isinstance(use_external_id, bool):
                raise TypeError("Invalid type for `use_external_id`, type has to be `bool`")

        self._use_external_id = use_external_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SimpleEncodingVodJobS3RoleBasedCredentials, self), "to_dict"):
            result = super(SimpleEncodingVodJobS3RoleBasedCredentials, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobS3RoleBasedCredentials):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.manifest_api import ManifestApi
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.error.error_api import ErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.finished.finished_api import FinishedApi
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.notification_list_query_params import NotificationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class LiveOptionsEntry(object):
    @poscheck_model
    def __init__(self,
                 units_used=None):
        # type: (int) -> None

        self._units_used = None
        self.discriminator = None

        if units_used is not None:
            self.units_used = units_used

    @property
    def openapi_types(self):
        types = {
            'units_used': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'units_used': 'unitsUsed'
        }
        return attributes

    @property
    def units_used(self):
        # type: () -> int
        """Gets the units_used of this LiveOptionsEntry.

        Live option units used (required)

        :return: The units_used of this LiveOptionsEntry.
        :rtype: int
        """
        return self._units_used

    @units_used.setter
    def units_used(self, units_used):
        # type: (int) -> None
        """Sets the units_used of this LiveOptionsEntry.

        Live option units used (required)

        :param units_used: The units_used of this LiveOptionsEntry.
        :type: int
        """

        if units_used is not None:
            if not isinstance(units_used, int):
                raise TypeError("Invalid type for `units_used`, type has to be `int`")

        self._units_used = units_used

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveOptionsEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AdaptationSetRole(Enum):
    ALTERNATE = "ALTERNATE"
    CAPTION = "CAPTION"
    COMMENTARY = "COMMENTARY"
    DUB = "DUB"
    MAIN = "MAIN"
    SUBTITLE = "SUBTITLE"
    SUPPLEMENTARY = "SUPPLEMENTARY"



from bitmovin_api_sdk.encoding.configurations.audio.dolby_atmos.dolby_atmos_api import DolbyAtmosApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_atmos.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_atmos.dolby_atmos_audio_configuration_list_query_params import DolbyAtmosAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input import Input
import pprint
import six


class RedundantRtmpInput(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 delay_threshold=None,
                 ingest_points=None,
                 static_ingest_points=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, list[RtmpIngestPoint], list[StaticRtmpIngestPoint]) -> None
        super(RedundantRtmpInput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._delay_threshold = None
        self._ingest_points = list()
        self._static_ingest_points = list()
        self.discriminator = None

        if delay_threshold is not None:
            self.delay_threshold = delay_threshold
        if ingest_points is not None:
            self.ingest_points = ingest_points
        if static_ingest_points is not None:
            self.static_ingest_points = static_ingest_points

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(RedundantRtmpInput, self), 'openapi_types'):
            types = getattr(super(RedundantRtmpInput, self), 'openapi_types')

        types.update({
            'delay_threshold': 'int',
            'ingest_points': 'list[RtmpIngestPoint]',
            'static_ingest_points': 'list[StaticRtmpIngestPoint]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(RedundantRtmpInput, self), 'attribute_map'):
            attributes = getattr(super(RedundantRtmpInput, self), 'attribute_map')

        attributes.update({
            'delay_threshold': 'delayThreshold',
            'ingest_points': 'ingestPoints',
            'static_ingest_points': 'staticIngestPoints'
        })
        return attributes

    @property
    def delay_threshold(self):
        # type: () -> int
        """Gets the delay_threshold of this RedundantRtmpInput.

        When there is no input signal present and this threshold in seconds is reached it will switch to another ingest point

        :return: The delay_threshold of this RedundantRtmpInput.
        :rtype: int
        """
        return self._delay_threshold

    @delay_threshold.setter
    def delay_threshold(self, delay_threshold):
        # type: (int) -> None
        """Sets the delay_threshold of this RedundantRtmpInput.

        When there is no input signal present and this threshold in seconds is reached it will switch to another ingest point

        :param delay_threshold: The delay_threshold of this RedundantRtmpInput.
        :type: int
        """

        if delay_threshold is not None:
            if not isinstance(delay_threshold, int):
                raise TypeError("Invalid type for `delay_threshold`, type has to be `int`")

        self._delay_threshold = delay_threshold

    @property
    def ingest_points(self):
        # type: () -> list[RtmpIngestPoint]
        """Gets the ingest_points of this RedundantRtmpInput.

        Configuration for ingest points that use a dynamic IP based endpoint to stream to e.g.: rtmp://41.167.11.21/live Either ingestPoints **or** staticIngestPoints can be set 

        :return: The ingest_points of this RedundantRtmpInput.
        :rtype: list[RtmpIngestPoint]
        """
        return self._ingest_points

    @ingest_points.setter
    def ingest_points(self, ingest_points):
        # type: (list) -> None
        """Sets the ingest_points of this RedundantRtmpInput.

        Configuration for ingest points that use a dynamic IP based endpoint to stream to e.g.: rtmp://41.167.11.21/live Either ingestPoints **or** staticIngestPoints can be set 

        :param ingest_points: The ingest_points of this RedundantRtmpInput.
        :type: list[RtmpIngestPoint]
        """

        if ingest_points is not None:
            if not isinstance(ingest_points, list):
                raise TypeError("Invalid type for `ingest_points`, type has to be `list[RtmpIngestPoint]`")

        self._ingest_points = ingest_points

    @property
    def static_ingest_points(self):
        # type: () -> list[StaticRtmpIngestPoint]
        """Gets the static_ingest_points of this RedundantRtmpInput.

        Configuration for static ingest points. These ingest points use a consistent endpoint to stream to e.g.: rtmps://live-ingest.bitmovin.com/live Either ingestPoints **or** staticIngestPoints can be set 

        :return: The static_ingest_points of this RedundantRtmpInput.
        :rtype: list[StaticRtmpIngestPoint]
        """
        return self._static_ingest_points

    @static_ingest_points.setter
    def static_ingest_points(self, static_ingest_points):
        # type: (list) -> None
        """Sets the static_ingest_points of this RedundantRtmpInput.

        Configuration for static ingest points. These ingest points use a consistent endpoint to stream to e.g.: rtmps://live-ingest.bitmovin.com/live Either ingestPoints **or** staticIngestPoints can be set 

        :param static_ingest_points: The static_ingest_points of this RedundantRtmpInput.
        :type: list[StaticRtmpIngestPoint]
        """

        if static_ingest_points is not None:
            if not isinstance(static_ingest_points, list):
                raise TypeError("Invalid type for `static_ingest_points`, type has to be `list[StaticRtmpIngestPoint]`")

        self._static_ingest_points = static_ingest_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(RedundantRtmpInput, self), "to_dict"):
            result = super(RedundantRtmpInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RedundantRtmpInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class StreamKeyListQueryParams(object):
    def __init__(self, offset=None, limit=None, sort=None, type_=None, status=None, assigned_ingest_point_id=None, assigned_encoding_id=None):
        # type: (int, int, string_types, string_types, string_types, string_types, string_types) -> None
        super(StreamKeyListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit
        self.sort = sort
        self.type = type_
        self.status = status
        self.assigned_ingest_point_id = assigned_ingest_point_id
        self.assigned_encoding_id = assigned_encoding_id

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int',
            'sort': 'string_types',
            'type': 'string_types',
            'status': 'string_types',
            'assigned_ingest_point_id': 'string_types',
            'assigned_encoding_id': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit',
            'sort': 'sort',
            'type': 'type',
            'status': 'status',
            'assigned_ingest_point_id': 'assignedIngestPointId',
            'assigned_encoding_id': 'assignedEncodingId'
        }

        return attributes



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_http_request_type import AnalyticsHttpRequestType
import pprint
import six


class AnalyticsHttpRequest(object):
    @poscheck_model
    def __init__(self,
                 client_time=None,
                 type_=None,
                 url=None,
                 last_redirect_location=None,
                 http_status=None,
                 download_time=None,
                 time_to_first_byte=None,
                 size=None,
                 success=None):
        # type: (datetime, AnalyticsHttpRequestType, string_types, string_types, int, int, int, int, bool) -> None

        self._client_time = None
        self._type = None
        self._url = None
        self._last_redirect_location = None
        self._http_status = None
        self._download_time = None
        self._time_to_first_byte = None
        self._size = None
        self._success = None
        self.discriminator = None

        if client_time is not None:
            self.client_time = client_time
        if type_ is not None:
            self.type = type_
        if url is not None:
            self.url = url
        if last_redirect_location is not None:
            self.last_redirect_location = last_redirect_location
        if http_status is not None:
            self.http_status = http_status
        if download_time is not None:
            self.download_time = download_time
        if time_to_first_byte is not None:
            self.time_to_first_byte = time_to_first_byte
        if size is not None:
            self.size = size
        if success is not None:
            self.success = success

    @property
    def openapi_types(self):
        types = {
            'client_time': 'datetime',
            'type': 'AnalyticsHttpRequestType',
            'url': 'string_types',
            'last_redirect_location': 'string_types',
            'http_status': 'int',
            'download_time': 'int',
            'time_to_first_byte': 'int',
            'size': 'int',
            'success': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'client_time': 'clientTime',
            'type': 'type',
            'url': 'url',
            'last_redirect_location': 'lastRedirectLocation',
            'http_status': 'httpStatus',
            'download_time': 'downloadTime',
            'time_to_first_byte': 'timeToFirstByte',
            'size': 'size',
            'success': 'success'
        }
        return attributes

    @property
    def client_time(self):
        # type: () -> datetime
        """Gets the client_time of this AnalyticsHttpRequest.

        Client timestamp

        :return: The client_time of this AnalyticsHttpRequest.
        :rtype: datetime
        """
        return self._client_time

    @client_time.setter
    def client_time(self, client_time):
        # type: (datetime) -> None
        """Sets the client_time of this AnalyticsHttpRequest.

        Client timestamp

        :param client_time: The client_time of this AnalyticsHttpRequest.
        :type: datetime
        """

        if client_time is not None:
            if not isinstance(client_time, datetime):
                raise TypeError("Invalid type for `client_time`, type has to be `datetime`")

        self._client_time = client_time

    @property
    def type(self):
        # type: () -> AnalyticsHttpRequestType
        """Gets the type of this AnalyticsHttpRequest.


        :return: The type of this AnalyticsHttpRequest.
        :rtype: AnalyticsHttpRequestType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (AnalyticsHttpRequestType) -> None
        """Sets the type of this AnalyticsHttpRequest.


        :param type_: The type of this AnalyticsHttpRequest.
        :type: AnalyticsHttpRequestType
        """

        if type_ is not None:
            if not isinstance(type_, AnalyticsHttpRequestType):
                raise TypeError("Invalid type for `type`, type has to be `AnalyticsHttpRequestType`")

        self._type = type_

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this AnalyticsHttpRequest.

        Http request URL

        :return: The url of this AnalyticsHttpRequest.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this AnalyticsHttpRequest.

        Http request URL

        :param url: The url of this AnalyticsHttpRequest.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def last_redirect_location(self):
        # type: () -> string_types
        """Gets the last_redirect_location of this AnalyticsHttpRequest.

        Last redirect location

        :return: The last_redirect_location of this AnalyticsHttpRequest.
        :rtype: string_types
        """
        return self._last_redirect_location

    @last_redirect_location.setter
    def last_redirect_location(self, last_redirect_location):
        # type: (string_types) -> None
        """Sets the last_redirect_location of this AnalyticsHttpRequest.

        Last redirect location

        :param last_redirect_location: The last_redirect_location of this AnalyticsHttpRequest.
        :type: string_types
        """

        if last_redirect_location is not None:
            if not isinstance(last_redirect_location, string_types):
                raise TypeError("Invalid type for `last_redirect_location`, type has to be `string_types`")

        self._last_redirect_location = last_redirect_location

    @property
    def http_status(self):
        # type: () -> int
        """Gets the http_status of this AnalyticsHttpRequest.

        Http request status

        :return: The http_status of this AnalyticsHttpRequest.
        :rtype: int
        """
        return self._http_status

    @http_status.setter
    def http_status(self, http_status):
        # type: (int) -> None
        """Sets the http_status of this AnalyticsHttpRequest.

        Http request status

        :param http_status: The http_status of this AnalyticsHttpRequest.
        :type: int
        """

        if http_status is not None:
            if not isinstance(http_status, int):
                raise TypeError("Invalid type for `http_status`, type has to be `int`")

        self._http_status = http_status

    @property
    def download_time(self):
        # type: () -> int
        """Gets the download_time of this AnalyticsHttpRequest.

        Download time

        :return: The download_time of this AnalyticsHttpRequest.
        :rtype: int
        """
        return self._download_time

    @download_time.setter
    def download_time(self, download_time):
        # type: (int) -> None
        """Sets the download_time of this AnalyticsHttpRequest.

        Download time

        :param download_time: The download_time of this AnalyticsHttpRequest.
        :type: int
        """

        if download_time is not None:
            if not isinstance(download_time, int):
                raise TypeError("Invalid type for `download_time`, type has to be `int`")

        self._download_time = download_time

    @property
    def time_to_first_byte(self):
        # type: () -> int
        """Gets the time_to_first_byte of this AnalyticsHttpRequest.

        Time to first byte

        :return: The time_to_first_byte of this AnalyticsHttpRequest.
        :rtype: int
        """
        return self._time_to_first_byte

    @time_to_first_byte.setter
    def time_to_first_byte(self, time_to_first_byte):
        # type: (int) -> None
        """Sets the time_to_first_byte of this AnalyticsHttpRequest.

        Time to first byte

        :param time_to_first_byte: The time_to_first_byte of this AnalyticsHttpRequest.
        :type: int
        """

        if time_to_first_byte is not None:
            if not isinstance(time_to_first_byte, int):
                raise TypeError("Invalid type for `time_to_first_byte`, type has to be `int`")

        self._time_to_first_byte = time_to_first_byte

    @property
    def size(self):
        # type: () -> int
        """Gets the size of this AnalyticsHttpRequest.

        Size

        :return: The size of this AnalyticsHttpRequest.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        # type: (int) -> None
        """Sets the size of this AnalyticsHttpRequest.

        Size

        :param size: The size of this AnalyticsHttpRequest.
        :type: int
        """

        if size is not None:
            if not isinstance(size, int):
                raise TypeError("Invalid type for `size`, type has to be `int`")

        self._size = size

    @property
    def success(self):
        # type: () -> bool
        """Gets the success of this AnalyticsHttpRequest.

        Was http request successful

        :return: The success of this AnalyticsHttpRequest.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        # type: (bool) -> None
        """Sets the success of this AnalyticsHttpRequest.

        Was http request successful

        :param success: The success of this AnalyticsHttpRequest.
        :type: bool
        """

        if success is not None:
            if not isinstance(success, bool):
                raise TypeError("Invalid type for `success`, type has to be `bool`")

        self._success = success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsHttpRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.analytics.ads.queries.queries_api import QueriesApi
from bitmovin_api_sdk.analytics.ads.queries.count.count_api import CountApi
from bitmovin_api_sdk.analytics.ads.queries.sum.sum_api import SumApi
from bitmovin_api_sdk.analytics.ads.queries.avg.avg_api import AvgApi
from bitmovin_api_sdk.analytics.ads.queries.min.min_api import MinApi
from bitmovin_api_sdk.analytics.ads.queries.max.max_api import MaxApi
from bitmovin_api_sdk.analytics.ads.queries.stddev.stddev_api import StddevApi
from bitmovin_api_sdk.analytics.ads.queries.percentile.percentile_api import PercentileApi
from bitmovin_api_sdk.analytics.ads.queries.variance.variance_api import VarianceApi
from bitmovin_api_sdk.analytics.ads.queries.median.median_api import MedianApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.manifest import Manifest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.dash_api import DashApi
from bitmovin_api_sdk.encoding.manifests.hls.hls_api import HlsApi
from bitmovin_api_sdk.encoding.manifests.smooth.smooth_api import SmoothApi
from bitmovin_api_sdk.encoding.manifests.manifest_list_query_params import ManifestListQueryParams


class ManifestsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ManifestsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dash = DashApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.hls = HlsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.smooth = SmoothApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (ManifestListQueryParams, dict) -> Manifest
        """List all Manifests

        :param query_params: Query parameters
        :type query_params: ManifestListQueryParams
        :return: All manifests with type information
        :rtype: Manifest
        """

        return self.api_client.get(
            '/encoding/manifests',
            query_params=query_params,
            pagination_response=True,
            type=Manifest,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsOutputType(Enum):
    S3_ROLE_BASED = "S3_ROLE_BASED"
    GCS_SERVICE_ACCOUNT = "GCS_SERVICE_ACCOUNT"
    AZURE = "AZURE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class BillableEncodingMinutesDetails(object):
    @poscheck_model
    def __init__(self,
                 unknown=None,
                 audio=None,
                 sd=None,
                 hd=None,
                 uhd=None):
        # type: (float, float, float, float, float) -> None

        self._unknown = None
        self._audio = None
        self._sd = None
        self._hd = None
        self._uhd = None
        self.discriminator = None

        if unknown is not None:
            self.unknown = unknown
        if audio is not None:
            self.audio = audio
        if sd is not None:
            self.sd = sd
        if hd is not None:
            self.hd = hd
        if uhd is not None:
            self.uhd = uhd

    @property
    def openapi_types(self):
        types = {
            'unknown': 'float',
            'audio': 'float',
            'sd': 'float',
            'hd': 'float',
            'uhd': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'unknown': 'UNKNOWN',
            'audio': 'AUDIO',
            'sd': 'SD',
            'hd': 'HD',
            'uhd': 'UHD'
        }
        return attributes

    @property
    def unknown(self):
        # type: () -> float
        """Gets the unknown of this BillableEncodingMinutesDetails.

        Only set if resolution information is not present.

        :return: The unknown of this BillableEncodingMinutesDetails.
        :rtype: float
        """
        return self._unknown

    @unknown.setter
    def unknown(self, unknown):
        # type: (float) -> None
        """Sets the unknown of this BillableEncodingMinutesDetails.

        Only set if resolution information is not present.

        :param unknown: The unknown of this BillableEncodingMinutesDetails.
        :type: float
        """

        if unknown is not None:
            if not isinstance(unknown, (float, int)):
                raise TypeError("Invalid type for `unknown`, type has to be `float`")

        self._unknown = unknown

    @property
    def audio(self):
        # type: () -> float
        """Gets the audio of this BillableEncodingMinutesDetails.

        Billable minutes for audio. Available if stream is an audio stream.

        :return: The audio of this BillableEncodingMinutesDetails.
        :rtype: float
        """
        return self._audio

    @audio.setter
    def audio(self, audio):
        # type: (float) -> None
        """Sets the audio of this BillableEncodingMinutesDetails.

        Billable minutes for audio. Available if stream is an audio stream.

        :param audio: The audio of this BillableEncodingMinutesDetails.
        :type: float
        """

        if audio is not None:
            if not isinstance(audio, (float, int)):
                raise TypeError("Invalid type for `audio`, type has to be `float`")

        self._audio = audio

    @property
    def sd(self):
        # type: () -> float
        """Gets the sd of this BillableEncodingMinutesDetails.

        Billable minutes for SD resolutions.

        :return: The sd of this BillableEncodingMinutesDetails.
        :rtype: float
        """
        return self._sd

    @sd.setter
    def sd(self, sd):
        # type: (float) -> None
        """Sets the sd of this BillableEncodingMinutesDetails.

        Billable minutes for SD resolutions.

        :param sd: The sd of this BillableEncodingMinutesDetails.
        :type: float
        """

        if sd is not None:
            if not isinstance(sd, (float, int)):
                raise TypeError("Invalid type for `sd`, type has to be `float`")

        self._sd = sd

    @property
    def hd(self):
        # type: () -> float
        """Gets the hd of this BillableEncodingMinutesDetails.

        Billable minutes for HD resolutions.

        :return: The hd of this BillableEncodingMinutesDetails.
        :rtype: float
        """
        return self._hd

    @hd.setter
    def hd(self, hd):
        # type: (float) -> None
        """Sets the hd of this BillableEncodingMinutesDetails.

        Billable minutes for HD resolutions.

        :param hd: The hd of this BillableEncodingMinutesDetails.
        :type: float
        """

        if hd is not None:
            if not isinstance(hd, (float, int)):
                raise TypeError("Invalid type for `hd`, type has to be `float`")

        self._hd = hd

    @property
    def uhd(self):
        # type: () -> float
        """Gets the uhd of this BillableEncodingMinutesDetails.

        Billable minutes for UHD resolutions.

        :return: The uhd of this BillableEncodingMinutesDetails.
        :rtype: float
        """
        return self._uhd

    @uhd.setter
    def uhd(self, uhd):
        # type: (float) -> None
        """Sets the uhd of this BillableEncodingMinutesDetails.

        Billable minutes for UHD resolutions.

        :param uhd: The uhd of this BillableEncodingMinutesDetails.
        :type: float
        """

        if uhd is not None:
            if not isinstance(uhd, (float, int)):
                raise TypeError("Invalid type for `uhd`, type has to be `float`")

        self._uhd = uhd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillableEncodingMinutesDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class StreamsDomainRestrictionResponse(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 allowed_domains=None,
                 allow_no_referer=None,
                 allow_share=None):
        # type: (string_types, list[string_types], bool, bool) -> None

        self._id = None
        self._allowed_domains = list()
        self._allow_no_referer = None
        self._allow_share = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if allowed_domains is not None:
            self.allowed_domains = allowed_domains
        if allow_no_referer is not None:
            self.allow_no_referer = allow_no_referer
        if allow_share is not None:
            self.allow_share = allow_share

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'allowed_domains': 'list[string_types]',
            'allow_no_referer': 'bool',
            'allow_share': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'allowed_domains': 'allowedDomains',
            'allow_no_referer': 'allowNoReferer',
            'allow_share': 'allowShare'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this StreamsDomainRestrictionResponse.

        The identifier of the streams domain restriction entity

        :return: The id of this StreamsDomainRestrictionResponse.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this StreamsDomainRestrictionResponse.

        The identifier of the streams domain restriction entity

        :param id_: The id of this StreamsDomainRestrictionResponse.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def allowed_domains(self):
        # type: () -> list[string_types]
        """Gets the allowed_domains of this StreamsDomainRestrictionResponse.

        The list of allowed domains

        :return: The allowed_domains of this StreamsDomainRestrictionResponse.
        :rtype: list[string_types]
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        # type: (list) -> None
        """Sets the allowed_domains of this StreamsDomainRestrictionResponse.

        The list of allowed domains

        :param allowed_domains: The allowed_domains of this StreamsDomainRestrictionResponse.
        :type: list[string_types]
        """

        if allowed_domains is not None:
            if not isinstance(allowed_domains, list):
                raise TypeError("Invalid type for `allowed_domains`, type has to be `list[string_types]`")

        self._allowed_domains = allowed_domains

    @property
    def allow_no_referer(self):
        # type: () -> bool
        """Gets the allow_no_referer of this StreamsDomainRestrictionResponse.

        Controls if requests to domain restricted streams without referer header should be allowed or denied

        :return: The allow_no_referer of this StreamsDomainRestrictionResponse.
        :rtype: bool
        """
        return self._allow_no_referer

    @allow_no_referer.setter
    def allow_no_referer(self, allow_no_referer):
        # type: (bool) -> None
        """Sets the allow_no_referer of this StreamsDomainRestrictionResponse.

        Controls if requests to domain restricted streams without referer header should be allowed or denied

        :param allow_no_referer: The allow_no_referer of this StreamsDomainRestrictionResponse.
        :type: bool
        """

        if allow_no_referer is not None:
            if not isinstance(allow_no_referer, bool):
                raise TypeError("Invalid type for `allow_no_referer`, type has to be `bool`")

        self._allow_no_referer = allow_no_referer

    @property
    def allow_share(self):
        # type: () -> bool
        """Gets the allow_share of this StreamsDomainRestrictionResponse.

        Controls if Stream is accessible via sharing URL or not

        :return: The allow_share of this StreamsDomainRestrictionResponse.
        :rtype: bool
        """
        return self._allow_share

    @allow_share.setter
    def allow_share(self, allow_share):
        # type: (bool) -> None
        """Sets the allow_share of this StreamsDomainRestrictionResponse.

        Controls if Stream is accessible via sharing URL or not

        :param allow_share: The allow_share of this StreamsDomainRestrictionResponse.
        :type: bool
        """

        if allow_share is not None:
            if not isinstance(allow_share, bool):
                raise TypeError("Invalid type for `allow_share`, type has to be `bool`")

        self._allow_share = allow_share

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamsDomainRestrictionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class StreamMetadata(object):
    @poscheck_model
    def __init__(self,
                 language=None):
        # type: (string_types) -> None

        self._language = None
        self.discriminator = None

        if language is not None:
            self.language = language

    @property
    def openapi_types(self):
        types = {
            'language': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'language': 'language'
        }
        return attributes

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this StreamMetadata.

        Language of the media contained in the stream. If the value is not set, then no metadata tag is set for the media stream.

        :return: The language of this StreamMetadata.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this StreamMetadata.

        Language of the media contained in the stream. If the value is not set, then no metadata tag is set for the media stream.

        :param language: The language of this StreamMetadata.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
from bitmovin_api_sdk.models.text_filter_font import TextFilterFont
import pprint
import six


class TextFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 font=None,
                 box=None,
                 box_border_width=None,
                 box_color=None,
                 line_spacing=None,
                 border_width=None,
                 fix_bounds=None,
                 font_color=None,
                 font_size=None,
                 font_size_expression=None,
                 alpha=None,
                 shadow_color=None,
                 shadow_x=None,
                 shadow_y=None,
                 timecode=None,
                 text=None,
                 x=None,
                 y=None,
                 rate=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, TextFilterFont, bool, int, string_types, int, int, bool, string_types, int, string_types, float, string_types, int, int, string_types, string_types, string_types, string_types, string_types) -> None
        super(TextFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._font = None
        self._box = None
        self._box_border_width = None
        self._box_color = None
        self._line_spacing = None
        self._border_width = None
        self._fix_bounds = None
        self._font_color = None
        self._font_size = None
        self._font_size_expression = None
        self._alpha = None
        self._shadow_color = None
        self._shadow_x = None
        self._shadow_y = None
        self._timecode = None
        self._text = None
        self._x = None
        self._y = None
        self._rate = None
        self.discriminator = None

        if font is not None:
            self.font = font
        if box is not None:
            self.box = box
        if box_border_width is not None:
            self.box_border_width = box_border_width
        if box_color is not None:
            self.box_color = box_color
        if line_spacing is not None:
            self.line_spacing = line_spacing
        if border_width is not None:
            self.border_width = border_width
        if fix_bounds is not None:
            self.fix_bounds = fix_bounds
        if font_color is not None:
            self.font_color = font_color
        if font_size is not None:
            self.font_size = font_size
        if font_size_expression is not None:
            self.font_size_expression = font_size_expression
        if alpha is not None:
            self.alpha = alpha
        if shadow_color is not None:
            self.shadow_color = shadow_color
        if shadow_x is not None:
            self.shadow_x = shadow_x
        if shadow_y is not None:
            self.shadow_y = shadow_y
        if timecode is not None:
            self.timecode = timecode
        if text is not None:
            self.text = text
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if rate is not None:
            self.rate = rate

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(TextFilter, self), 'openapi_types'):
            types = getattr(super(TextFilter, self), 'openapi_types')

        types.update({
            'font': 'TextFilterFont',
            'box': 'bool',
            'box_border_width': 'int',
            'box_color': 'string_types',
            'line_spacing': 'int',
            'border_width': 'int',
            'fix_bounds': 'bool',
            'font_color': 'string_types',
            'font_size': 'int',
            'font_size_expression': 'string_types',
            'alpha': 'float',
            'shadow_color': 'string_types',
            'shadow_x': 'int',
            'shadow_y': 'int',
            'timecode': 'string_types',
            'text': 'string_types',
            'x': 'string_types',
            'y': 'string_types',
            'rate': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(TextFilter, self), 'attribute_map'):
            attributes = getattr(super(TextFilter, self), 'attribute_map')

        attributes.update({
            'font': 'font',
            'box': 'box',
            'box_border_width': 'boxBorderWidth',
            'box_color': 'boxColor',
            'line_spacing': 'lineSpacing',
            'border_width': 'borderWidth',
            'fix_bounds': 'fixBounds',
            'font_color': 'fontColor',
            'font_size': 'fontSize',
            'font_size_expression': 'fontSizeExpression',
            'alpha': 'alpha',
            'shadow_color': 'shadowColor',
            'shadow_x': 'shadowX',
            'shadow_y': 'shadowY',
            'timecode': 'timecode',
            'text': 'text',
            'x': 'x',
            'y': 'y',
            'rate': 'rate'
        })
        return attributes

    @property
    def font(self):
        # type: () -> TextFilterFont
        """Gets the font of this TextFilter.


        :return: The font of this TextFilter.
        :rtype: TextFilterFont
        """
        return self._font

    @font.setter
    def font(self, font):
        # type: (TextFilterFont) -> None
        """Sets the font of this TextFilter.


        :param font: The font of this TextFilter.
        :type: TextFilterFont
        """

        if font is not None:
            if not isinstance(font, TextFilterFont):
                raise TypeError("Invalid type for `font`, type has to be `TextFilterFont`")

        self._font = font

    @property
    def box(self):
        # type: () -> bool
        """Gets the box of this TextFilter.

        If set to true a box is drawn around the text using the background color.

        :return: The box of this TextFilter.
        :rtype: bool
        """
        return self._box

    @box.setter
    def box(self, box):
        # type: (bool) -> None
        """Sets the box of this TextFilter.

        If set to true a box is drawn around the text using the background color.

        :param box: The box of this TextFilter.
        :type: bool
        """

        if box is not None:
            if not isinstance(box, bool):
                raise TypeError("Invalid type for `box`, type has to be `bool`")

        self._box = box

    @property
    def box_border_width(self):
        # type: () -> int
        """Gets the box_border_width of this TextFilter.

        The width of the box drawn around the text.

        :return: The box_border_width of this TextFilter.
        :rtype: int
        """
        return self._box_border_width

    @box_border_width.setter
    def box_border_width(self, box_border_width):
        # type: (int) -> None
        """Sets the box_border_width of this TextFilter.

        The width of the box drawn around the text.

        :param box_border_width: The box_border_width of this TextFilter.
        :type: int
        """

        if box_border_width is not None:
            if not isinstance(box_border_width, int):
                raise TypeError("Invalid type for `box_border_width`, type has to be `int`")

        self._box_border_width = box_border_width

    @property
    def box_color(self):
        # type: () -> string_types
        """Gets the box_color of this TextFilter.

        The background color to be used for drawing the box.

        :return: The box_color of this TextFilter.
        :rtype: string_types
        """
        return self._box_color

    @box_color.setter
    def box_color(self, box_color):
        # type: (string_types) -> None
        """Sets the box_color of this TextFilter.

        The background color to be used for drawing the box.

        :param box_color: The box_color of this TextFilter.
        :type: string_types
        """

        if box_color is not None:
            if not isinstance(box_color, string_types):
                raise TypeError("Invalid type for `box_color`, type has to be `string_types`")

        self._box_color = box_color

    @property
    def line_spacing(self):
        # type: () -> int
        """Gets the line_spacing of this TextFilter.

        Line spacing of the border around the box in pixels

        :return: The line_spacing of this TextFilter.
        :rtype: int
        """
        return self._line_spacing

    @line_spacing.setter
    def line_spacing(self, line_spacing):
        # type: (int) -> None
        """Sets the line_spacing of this TextFilter.

        Line spacing of the border around the box in pixels

        :param line_spacing: The line_spacing of this TextFilter.
        :type: int
        """

        if line_spacing is not None:
            if not isinstance(line_spacing, int):
                raise TypeError("Invalid type for `line_spacing`, type has to be `int`")

        self._line_spacing = line_spacing

    @property
    def border_width(self):
        # type: () -> int
        """Gets the border_width of this TextFilter.

        Width of the border around the text

        :return: The border_width of this TextFilter.
        :rtype: int
        """
        return self._border_width

    @border_width.setter
    def border_width(self, border_width):
        # type: (int) -> None
        """Sets the border_width of this TextFilter.

        Width of the border around the text

        :param border_width: The border_width of this TextFilter.
        :type: int
        """

        if border_width is not None:
            if not isinstance(border_width, int):
                raise TypeError("Invalid type for `border_width`, type has to be `int`")

        self._border_width = border_width

    @property
    def fix_bounds(self):
        # type: () -> bool
        """Gets the fix_bounds of this TextFilter.

        If set to true, it will fix text coordinates to avoid clipping if necessary

        :return: The fix_bounds of this TextFilter.
        :rtype: bool
        """
        return self._fix_bounds

    @fix_bounds.setter
    def fix_bounds(self, fix_bounds):
        # type: (bool) -> None
        """Sets the fix_bounds of this TextFilter.

        If set to true, it will fix text coordinates to avoid clipping if necessary

        :param fix_bounds: The fix_bounds of this TextFilter.
        :type: bool
        """

        if fix_bounds is not None:
            if not isinstance(fix_bounds, bool):
                raise TypeError("Invalid type for `fix_bounds`, type has to be `bool`")

        self._fix_bounds = fix_bounds

    @property
    def font_color(self):
        # type: () -> string_types
        """Gets the font_color of this TextFilter.

        The color to be used to draw the text

        :return: The font_color of this TextFilter.
        :rtype: string_types
        """
        return self._font_color

    @font_color.setter
    def font_color(self, font_color):
        # type: (string_types) -> None
        """Sets the font_color of this TextFilter.

        The color to be used to draw the text

        :param font_color: The font_color of this TextFilter.
        :type: string_types
        """

        if font_color is not None:
            if not isinstance(font_color, string_types):
                raise TypeError("Invalid type for `font_color`, type has to be `string_types`")

        self._font_color = font_color

    @property
    def font_size(self):
        # type: () -> int
        """Gets the font_size of this TextFilter.

        Font size to be used to draw the text

        :return: The font_size of this TextFilter.
        :rtype: int
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        # type: (int) -> None
        """Sets the font_size of this TextFilter.

        Font size to be used to draw the text

        :param font_size: The font_size of this TextFilter.
        :type: int
        """

        if font_size is not None:
            if not isinstance(font_size, int):
                raise TypeError("Invalid type for `font_size`, type has to be `int`")

        self._font_size = font_size

    @property
    def font_size_expression(self):
        # type: () -> string_types
        """Gets the font_size_expression of this TextFilter.

        An expression for the Font size. Either fontSize or fontSizeExpression can be set at the same time. The following variables are valid: main_h, h, H for input height and main_w, w, W for the input_width

        :return: The font_size_expression of this TextFilter.
        :rtype: string_types
        """
        return self._font_size_expression

    @font_size_expression.setter
    def font_size_expression(self, font_size_expression):
        # type: (string_types) -> None
        """Sets the font_size_expression of this TextFilter.

        An expression for the Font size. Either fontSize or fontSizeExpression can be set at the same time. The following variables are valid: main_h, h, H for input height and main_w, w, W for the input_width

        :param font_size_expression: The font_size_expression of this TextFilter.
        :type: string_types
        """

        if font_size_expression is not None:
            if not isinstance(font_size_expression, string_types):
                raise TypeError("Invalid type for `font_size_expression`, type has to be `string_types`")

        self._font_size_expression = font_size_expression

    @property
    def alpha(self):
        # type: () -> float
        """Gets the alpha of this TextFilter.

        If set, alpha blending for the text is applied. Values are valid between 0.0 and 1.0.

        :return: The alpha of this TextFilter.
        :rtype: float
        """
        return self._alpha

    @alpha.setter
    def alpha(self, alpha):
        # type: (float) -> None
        """Sets the alpha of this TextFilter.

        If set, alpha blending for the text is applied. Values are valid between 0.0 and 1.0.

        :param alpha: The alpha of this TextFilter.
        :type: float
        """

        if alpha is not None:
            if not isinstance(alpha, (float, int)):
                raise TypeError("Invalid type for `alpha`, type has to be `float`")

        self._alpha = alpha

    @property
    def shadow_color(self):
        # type: () -> string_types
        """Gets the shadow_color of this TextFilter.

        Color of the shadow

        :return: The shadow_color of this TextFilter.
        :rtype: string_types
        """
        return self._shadow_color

    @shadow_color.setter
    def shadow_color(self, shadow_color):
        # type: (string_types) -> None
        """Sets the shadow_color of this TextFilter.

        Color of the shadow

        :param shadow_color: The shadow_color of this TextFilter.
        :type: string_types
        """

        if shadow_color is not None:
            if not isinstance(shadow_color, string_types):
                raise TypeError("Invalid type for `shadow_color`, type has to be `string_types`")

        self._shadow_color = shadow_color

    @property
    def shadow_x(self):
        # type: () -> int
        """Gets the shadow_x of this TextFilter.

        X offset of the shadow

        :return: The shadow_x of this TextFilter.
        :rtype: int
        """
        return self._shadow_x

    @shadow_x.setter
    def shadow_x(self, shadow_x):
        # type: (int) -> None
        """Sets the shadow_x of this TextFilter.

        X offset of the shadow

        :param shadow_x: The shadow_x of this TextFilter.
        :type: int
        """

        if shadow_x is not None:
            if not isinstance(shadow_x, int):
                raise TypeError("Invalid type for `shadow_x`, type has to be `int`")

        self._shadow_x = shadow_x

    @property
    def shadow_y(self):
        # type: () -> int
        """Gets the shadow_y of this TextFilter.

        Y offset of the shadow

        :return: The shadow_y of this TextFilter.
        :rtype: int
        """
        return self._shadow_y

    @shadow_y.setter
    def shadow_y(self, shadow_y):
        # type: (int) -> None
        """Sets the shadow_y of this TextFilter.

        Y offset of the shadow

        :param shadow_y: The shadow_y of this TextFilter.
        :type: int
        """

        if shadow_y is not None:
            if not isinstance(shadow_y, int):
                raise TypeError("Invalid type for `shadow_y`, type has to be `int`")

        self._shadow_y = shadow_y

    @property
    def timecode(self):
        # type: () -> string_types
        """Gets the timecode of this TextFilter.

        If set, the timecode representation in \"hh:mm:ss[:;.]ff\" format will be applied. Drop-frame timecodes (containing \";\" or \".\") must only be used with video frame rates of 29.97, 30, 59.94 or 60 FPS, according to the SMPTE standard

        :return: The timecode of this TextFilter.
        :rtype: string_types
        """
        return self._timecode

    @timecode.setter
    def timecode(self, timecode):
        # type: (string_types) -> None
        """Sets the timecode of this TextFilter.

        If set, the timecode representation in \"hh:mm:ss[:;.]ff\" format will be applied. Drop-frame timecodes (containing \";\" or \".\") must only be used with video frame rates of 29.97, 30, 59.94 or 60 FPS, according to the SMPTE standard

        :param timecode: The timecode of this TextFilter.
        :type: string_types
        """

        if timecode is not None:
            if not isinstance(timecode, string_types):
                raise TypeError("Invalid type for `timecode`, type has to be `string_types`")

        self._timecode = timecode

    @property
    def text(self):
        # type: () -> string_types
        """Gets the text of this TextFilter.

        String to be drawn

        :return: The text of this TextFilter.
        :rtype: string_types
        """
        return self._text

    @text.setter
    def text(self, text):
        # type: (string_types) -> None
        """Sets the text of this TextFilter.

        String to be drawn

        :param text: The text of this TextFilter.
        :type: string_types
        """

        if text is not None:
            if not isinstance(text, string_types):
                raise TypeError("Invalid type for `text`, type has to be `string_types`")

        self._text = text

    @property
    def x(self):
        # type: () -> string_types
        """Gets the x of this TextFilter.

        X position of the text. Also an expression can be used. The following variables are valid: line_h - height of each text line; main_h - input height; main_w - input width; n - number of input frame; text_h - Text height; text_w - Text width (required)

        :return: The x of this TextFilter.
        :rtype: string_types
        """
        return self._x

    @x.setter
    def x(self, x):
        # type: (string_types) -> None
        """Sets the x of this TextFilter.

        X position of the text. Also an expression can be used. The following variables are valid: line_h - height of each text line; main_h - input height; main_w - input width; n - number of input frame; text_h - Text height; text_w - Text width (required)

        :param x: The x of this TextFilter.
        :type: string_types
        """

        if x is not None:
            if not isinstance(x, string_types):
                raise TypeError("Invalid type for `x`, type has to be `string_types`")

        self._x = x

    @property
    def y(self):
        # type: () -> string_types
        """Gets the y of this TextFilter.

        Y position of the text. Also an expression can be used. The following variables are valid: line_h - height of each text line; main_h - input height; main_w - input width; n - number of input frame; text_h - Text height; text_w - Text width (required)

        :return: The y of this TextFilter.
        :rtype: string_types
        """
        return self._y

    @y.setter
    def y(self, y):
        # type: (string_types) -> None
        """Sets the y of this TextFilter.

        Y position of the text. Also an expression can be used. The following variables are valid: line_h - height of each text line; main_h - input height; main_w - input width; n - number of input frame; text_h - Text height; text_w - Text width (required)

        :param y: The y of this TextFilter.
        :type: string_types
        """

        if y is not None:
            if not isinstance(y, string_types):
                raise TypeError("Invalid type for `y`, type has to be `string_types`")

        self._y = y

    @property
    def rate(self):
        # type: () -> string_types
        """Gets the rate of this TextFilter.

        Video frame rate

        :return: The rate of this TextFilter.
        :rtype: string_types
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (string_types) -> None
        """Sets the rate of this TextFilter.

        Video frame rate

        :param rate: The rate of this TextFilter.
        :type: string_types
        """

        if rate is not None:
            if not isinstance(rate, string_types):
                raise TypeError("Invalid type for `rate`, type has to be `string_types`")

        self._rate = rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(TextFilter, self), "to_dict"):
            result = super(TextFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TextFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.input_streams.concatenation.concatenation_api import ConcatenationApi
from bitmovin_api_sdk.encoding.encodings.input_streams.concatenation.concatenation_input_stream_list_query_params import ConcatenationInputStreamListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.encoding_statistics_vod import EncodingStatisticsVod
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.statistics.encodings.vod.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.encodings.vod.encoding_statistics_vod_list_query_params import EncodingStatisticsVodListQueryParams
from bitmovin_api_sdk.encoding.statistics.encodings.vod.encoding_statistics_vod_list_by_date_range_query_params import EncodingStatisticsVodListByDateRangeQueryParams


class VodApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VodApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.daily = DailyApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (EncodingStatisticsVodListQueryParams, dict) -> EncodingStatisticsVod
        """List VOD Encoding Statistics

        :param query_params: Query parameters
        :type query_params: EncodingStatisticsVodListQueryParams
        :return: List of VOD encoding statistics
        :rtype: EncodingStatisticsVod
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/vod',
            query_params=query_params,
            pagination_response=True,
            type=EncodingStatisticsVod,
            **kwargs
        )

    def list_by_date_range(self, from_, to, query_params=None, **kwargs):
        # type: (date, date, EncodingStatisticsVodListByDateRangeQueryParams, dict) -> EncodingStatisticsVod
        """List VOD Encoding Statistics Within Specific Dates

        :param from_: Start date, format: yyyy-MM-dd
        :type from_: date, required
        :param to: End date, format: yyyy-MM-dd
        :type to: date, required
        :param query_params: Query parameters
        :type query_params: EncodingStatisticsVodListByDateRangeQueryParams
        :return: List of VOD encoding statistics
        :rtype: EncodingStatisticsVod
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/vod/{from}/{to}',
            path_params={'from': from_, 'to': to},
            query_params=query_params,
            pagination_response=True,
            type=EncodingStatisticsVod,
            **kwargs
        )



from bitmovin_api_sdk.encoding.statistics.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.statistics.encodings.vod.vod_api import VodApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.live_statistics_api import LiveStatisticsApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class WebVttCueIdentifierPolicy(Enum):
    INCLUDE_IDENTIFIERS = "INCLUDE_IDENTIFIERS"
    OMIT_IDENTIFIERS = "OMIT_IDENTIFIERS"



from bitmovin_api_sdk.encoding.configurations.audio.opus.opus_api import OpusApi
from bitmovin_api_sdk.encoding.configurations.audio.opus.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.opus.opus_audio_configuration_list_query_params import OpusAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.simple_encoding_vod_job_input import SimpleEncodingVodJobInput
from bitmovin_api_sdk.models.simple_encoding_vod_job_input_type import SimpleEncodingVodJobInputType
import pprint
import six


class SimpleEncodingVodJobDirectFileUploadInput(SimpleEncodingVodJobInput):
    @poscheck_model
    def __init__(self,
                 input_id=None,
                 input_type=None,
                 language=None):
        # type: (string_types, SimpleEncodingVodJobInputType, string_types) -> None
        super(SimpleEncodingVodJobDirectFileUploadInput, self).__init__()

        self._input_id = None
        self._input_type = None
        self._language = None
        self.discriminator = None

        if input_id is not None:
            self.input_id = input_id
        if input_type is not None:
            self.input_type = input_type
        if language is not None:
            self.language = language

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SimpleEncodingVodJobDirectFileUploadInput, self), 'openapi_types'):
            types = getattr(super(SimpleEncodingVodJobDirectFileUploadInput, self), 'openapi_types')

        types.update({
            'input_id': 'string_types',
            'input_type': 'SimpleEncodingVodJobInputType',
            'language': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SimpleEncodingVodJobDirectFileUploadInput, self), 'attribute_map'):
            attributes = getattr(super(SimpleEncodingVodJobDirectFileUploadInput, self), 'attribute_map')

        attributes.update({
            'input_id': 'inputId',
            'input_type': 'inputType',
            'language': 'language'
        })
        return attributes

    @property
    def input_id(self):
        # type: () -> string_types
        """Gets the input_id of this SimpleEncodingVodJobDirectFileUploadInput.

        Id of a DirectFileUploadInput (required)

        :return: The input_id of this SimpleEncodingVodJobDirectFileUploadInput.
        :rtype: string_types
        """
        return self._input_id

    @input_id.setter
    def input_id(self, input_id):
        # type: (string_types) -> None
        """Sets the input_id of this SimpleEncodingVodJobDirectFileUploadInput.

        Id of a DirectFileUploadInput (required)

        :param input_id: The input_id of this SimpleEncodingVodJobDirectFileUploadInput.
        :type: string_types
        """

        if input_id is not None:
            if not isinstance(input_id, string_types):
                raise TypeError("Invalid type for `input_id`, type has to be `string_types`")

        self._input_id = input_id

    @property
    def input_type(self):
        # type: () -> SimpleEncodingVodJobInputType
        """Gets the input_type of this SimpleEncodingVodJobDirectFileUploadInput.

        Defines the type of the input file, if no type is set it is assumed that the input file contains at least one video stream and optionally one or multiple audio streams.  Note that when defining video and audio inputs, you can either - add one single input without inputType, in which case that source file must contain a video stream and (if you want audio) one audio stream, or - add one single input with inputType=VIDEO and (if you want audio) one or more inputs with inputType=AUDIO (each containing one audio stream)  Other combinations are not valid. 

        :return: The input_type of this SimpleEncodingVodJobDirectFileUploadInput.
        :rtype: SimpleEncodingVodJobInputType
        """
        return self._input_type

    @input_type.setter
    def input_type(self, input_type):
        # type: (SimpleEncodingVodJobInputType) -> None
        """Sets the input_type of this SimpleEncodingVodJobDirectFileUploadInput.

        Defines the type of the input file, if no type is set it is assumed that the input file contains at least one video stream and optionally one or multiple audio streams.  Note that when defining video and audio inputs, you can either - add one single input without inputType, in which case that source file must contain a video stream and (if you want audio) one audio stream, or - add one single input with inputType=VIDEO and (if you want audio) one or more inputs with inputType=AUDIO (each containing one audio stream)  Other combinations are not valid. 

        :param input_type: The input_type of this SimpleEncodingVodJobDirectFileUploadInput.
        :type: SimpleEncodingVodJobInputType
        """

        if input_type is not None:
            if not isinstance(input_type, SimpleEncodingVodJobInputType):
                raise TypeError("Invalid type for `input_type`, type has to be `SimpleEncodingVodJobInputType`")

        self._input_type = input_type

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this SimpleEncodingVodJobDirectFileUploadInput.

        The language of the audio track, the subtitles, or closed captions file. The language code  must be compliant with [BCP 47](https://datatracker.ietf.org/doc/html/rfc5646).  This property is mandatory if the input provided is of type SUBTITLES or CLOSED_CAPTIONS and  recommended for input type AUDIO and an input that does not specify an input type (combined  audio and video). If an audio input does not specify the language, it is defaulted to `und`  (undefined). 

        :return: The language of this SimpleEncodingVodJobDirectFileUploadInput.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this SimpleEncodingVodJobDirectFileUploadInput.

        The language of the audio track, the subtitles, or closed captions file. The language code  must be compliant with [BCP 47](https://datatracker.ietf.org/doc/html/rfc5646).  This property is mandatory if the input provided is of type SUBTITLES or CLOSED_CAPTIONS and  recommended for input type AUDIO and an input that does not specify an input type (combined  audio and video). If an audio input does not specify the language, it is defaulted to `und`  (undefined). 

        :param language: The language of this SimpleEncodingVodJobDirectFileUploadInput.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SimpleEncodingVodJobDirectFileUploadInput, self), "to_dict"):
            result = super(SimpleEncodingVodJobDirectFileUploadInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobDirectFileUploadInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsExportType(Enum):
    ADS = "ADS"
    SESSIONS = "SESSIONS"



class LiveOptionsStatisticsListByDateRangeQueryParams(object):
    def __init__(self, from_=None, to=None, offset=None, limit=None):
        # type: (date, date, int, int) -> None
        super(LiveOptionsStatisticsListByDateRangeQueryParams, self).__init__()

        self.from_ = from_
        self.to = to
        self.offset = offset
        self.limit = limit

    @property
    def openapi_types(self):
        types = {
            'from_': 'date',
            'to': 'date',
            'offset': 'int',
            'limit': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'from_': 'from',
            'to': 'to',
            'offset': 'offset',
            'limit': 'limit'
        }

        return attributes



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PresetConfiguration(Enum):
    LIVE_ULTRAHIGH_QUALITY = "LIVE_ULTRAHIGH_QUALITY"
    LIVE_VERYHIGH_QUALITY = "LIVE_VERYHIGH_QUALITY"
    LIVE_HIGH_QUALITY = "LIVE_HIGH_QUALITY"
    LIVE_STANDARD = "LIVE_STANDARD"
    LIVE_LOW_LATENCY = "LIVE_LOW_LATENCY"
    LIVE_LOWER_LATENCY = "LIVE_LOWER_LATENCY"
    LIVE_VERYLOW_LATENCY = "LIVE_VERYLOW_LATENCY"
    VOD_HIGH_QUALITY = "VOD_HIGH_QUALITY"
    VOD_QUALITY = "VOD_QUALITY"
    VOD_STANDARD = "VOD_STANDARD"
    VOD_SPEED = "VOD_SPEED"
    VOD_HIGH_SPEED = "VOD_HIGH_SPEED"
    VOD_VERYHIGH_SPEED = "VOD_VERYHIGH_SPEED"
    VOD_EXTRAHIGH_SPEED = "VOD_EXTRAHIGH_SPEED"
    VOD_SUPERHIGH_SPEED = "VOD_SUPERHIGH_SPEED"
    VOD_ULTRAHIGH_SPEED = "VOD_ULTRAHIGH_SPEED"
    VOD_HARDWARE_SHORTFORM = "VOD_HARDWARE_SHORTFORM"



from bitmovin_api_sdk.streams.live.live_api import LiveApi
from bitmovin_api_sdk.streams.live.stop.stop_api import StopApi
from bitmovin_api_sdk.streams.live.start.start_api import StartApi
from bitmovin_api_sdk.streams.live.streams_live_response_list_query_params import StreamsLiveResponseListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashRepresentationTypeMode(Enum):
    TEMPLATE_REPRESENTATION = "TEMPLATE_REPRESENTATION"
    TEMPLATE_ADAPTATION_SET = "TEMPLATE_ADAPTATION_SET"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream_key import StreamKey
from bitmovin_api_sdk.encoding.live.stream_keys.actions.actions_api import ActionsApi
from bitmovin_api_sdk.encoding.live.stream_keys.stream_key_list_query_params import StreamKeyListQueryParams


class StreamKeysApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StreamKeysApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.actions = ActionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, stream_key, **kwargs):
        # type: (StreamKey, dict) -> StreamKey
        """Create new stream key

        :param stream_key: The stream key to be created
        :type stream_key: StreamKey, required
        :return:
        :rtype: StreamKey
        """

        return self.api_client.post(
            '/encoding/live/stream-keys',
            stream_key,
            type=StreamKey,
            **kwargs
        )

    def delete(self, stream_key_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Stream Key

        :param stream_key_id: Id of the stream key
        :type stream_key_id: string_types, required
        :return: Id of the stream key that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/live/stream-keys/{stream_key_id}',
            path_params={'stream_key_id': stream_key_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, stream_key_id, **kwargs):
        # type: (string_types, dict) -> StreamKey
        """Stream Key details

        :param stream_key_id: Id of the stream key
        :type stream_key_id: string_types, required
        :return: Stream key
        :rtype: StreamKey
        """

        return self.api_client.get(
            '/encoding/live/stream-keys/{stream_key_id}',
            path_params={'stream_key_id': stream_key_id},
            type=StreamKey,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (StreamKeyListQueryParams, dict) -> StreamKey
        """List Stream Keys

        :param query_params: Query parameters
        :type query_params: StreamKeyListQueryParams
        :return: Stream key list response
        :rtype: StreamKey
        """

        return self.api_client.get(
            '/encoding/live/stream-keys',
            query_params=query_params,
            pagination_response=True,
            type=StreamKey,
            **kwargs
        )



from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v1.he_aac_v1_api import HeAacV1Api
from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v1.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.he_aac_v1.he_aac_v1_audio_configuration_list_query_params import HeAacV1AudioConfigurationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.akamai_msl_output import AkamaiMslOutput
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.akamai_msl.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.akamai_msl.akamai_msl_output_list_query_params import AkamaiMslOutputListQueryParams


class AkamaiMslApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AkamaiMslApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, akamai_msl_output, **kwargs):
        # type: (AkamaiMslOutput, dict) -> AkamaiMslOutput
        """Create Akamai MSL Output

        :param akamai_msl_output: The Akamai MSL output to be created
        :type akamai_msl_output: AkamaiMslOutput, required
        :return: Akamai MSL output
        :rtype: AkamaiMslOutput
        """

        return self.api_client.post(
            '/encoding/outputs/akamai-msl',
            akamai_msl_output,
            type=AkamaiMslOutput,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Akamai MSL Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the output
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/outputs/akamai-msl/{output_id}',
            path_params={'output_id': output_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> AkamaiMslOutput
        """Akamai MSL Output Details

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Akamai MSL output
        :rtype: AkamaiMslOutput
        """

        return self.api_client.get(
            '/encoding/outputs/akamai-msl/{output_id}',
            path_params={'output_id': output_id},
            type=AkamaiMslOutput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AkamaiMslOutputListQueryParams, dict) -> AkamaiMslOutput
        """List Akamai MSL Outputs

        :param query_params: Query parameters
        :type query_params: AkamaiMslOutputListQueryParams
        :return: List of Akamai MSL outputs
        :rtype: AkamaiMslOutput
        """

        return self.api_client.get(
            '/encoding/outputs/akamai-msl',
            query_params=query_params,
            pagination_response=True,
            type=AkamaiMslOutput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class StreamsStyleConfigPlayerStyle(object):
    @poscheck_model
    def __init__(self,
                 playback_marker_bg_color=None,
                 playback_marker_border_color=None,
                 playback_track_played_color=None,
                 playback_track_buffered_color=None,
                 playback_track_bg_color=None,
                 text_color=None,
                 background_color=None):
        # type: (string_types, string_types, string_types, string_types, string_types, string_types, string_types) -> None

        self._playback_marker_bg_color = None
        self._playback_marker_border_color = None
        self._playback_track_played_color = None
        self._playback_track_buffered_color = None
        self._playback_track_bg_color = None
        self._text_color = None
        self._background_color = None
        self.discriminator = None

        if playback_marker_bg_color is not None:
            self.playback_marker_bg_color = playback_marker_bg_color
        if playback_marker_border_color is not None:
            self.playback_marker_border_color = playback_marker_border_color
        if playback_track_played_color is not None:
            self.playback_track_played_color = playback_track_played_color
        if playback_track_buffered_color is not None:
            self.playback_track_buffered_color = playback_track_buffered_color
        if playback_track_bg_color is not None:
            self.playback_track_bg_color = playback_track_bg_color
        if text_color is not None:
            self.text_color = text_color
        if background_color is not None:
            self.background_color = background_color

    @property
    def openapi_types(self):
        types = {
            'playback_marker_bg_color': 'string_types',
            'playback_marker_border_color': 'string_types',
            'playback_track_played_color': 'string_types',
            'playback_track_buffered_color': 'string_types',
            'playback_track_bg_color': 'string_types',
            'text_color': 'string_types',
            'background_color': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'playback_marker_bg_color': 'playbackMarkerBgColor',
            'playback_marker_border_color': 'playbackMarkerBorderColor',
            'playback_track_played_color': 'playbackTrackPlayedColor',
            'playback_track_buffered_color': 'playbackTrackBufferedColor',
            'playback_track_bg_color': 'playbackTrackBgColor',
            'text_color': 'textColor',
            'background_color': 'backgroundColor'
        }
        return attributes

    @property
    def playback_marker_bg_color(self):
        # type: () -> string_types
        """Gets the playback_marker_bg_color of this StreamsStyleConfigPlayerStyle.

        Playback marker background color

        :return: The playback_marker_bg_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._playback_marker_bg_color

    @playback_marker_bg_color.setter
    def playback_marker_bg_color(self, playback_marker_bg_color):
        # type: (string_types) -> None
        """Sets the playback_marker_bg_color of this StreamsStyleConfigPlayerStyle.

        Playback marker background color

        :param playback_marker_bg_color: The playback_marker_bg_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if playback_marker_bg_color is not None:
            if not isinstance(playback_marker_bg_color, string_types):
                raise TypeError("Invalid type for `playback_marker_bg_color`, type has to be `string_types`")

        self._playback_marker_bg_color = playback_marker_bg_color

    @property
    def playback_marker_border_color(self):
        # type: () -> string_types
        """Gets the playback_marker_border_color of this StreamsStyleConfigPlayerStyle.

        Playback marker border color

        :return: The playback_marker_border_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._playback_marker_border_color

    @playback_marker_border_color.setter
    def playback_marker_border_color(self, playback_marker_border_color):
        # type: (string_types) -> None
        """Sets the playback_marker_border_color of this StreamsStyleConfigPlayerStyle.

        Playback marker border color

        :param playback_marker_border_color: The playback_marker_border_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if playback_marker_border_color is not None:
            if not isinstance(playback_marker_border_color, string_types):
                raise TypeError("Invalid type for `playback_marker_border_color`, type has to be `string_types`")

        self._playback_marker_border_color = playback_marker_border_color

    @property
    def playback_track_played_color(self):
        # type: () -> string_types
        """Gets the playback_track_played_color of this StreamsStyleConfigPlayerStyle.

        Playback track played color

        :return: The playback_track_played_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._playback_track_played_color

    @playback_track_played_color.setter
    def playback_track_played_color(self, playback_track_played_color):
        # type: (string_types) -> None
        """Sets the playback_track_played_color of this StreamsStyleConfigPlayerStyle.

        Playback track played color

        :param playback_track_played_color: The playback_track_played_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if playback_track_played_color is not None:
            if not isinstance(playback_track_played_color, string_types):
                raise TypeError("Invalid type for `playback_track_played_color`, type has to be `string_types`")

        self._playback_track_played_color = playback_track_played_color

    @property
    def playback_track_buffered_color(self):
        # type: () -> string_types
        """Gets the playback_track_buffered_color of this StreamsStyleConfigPlayerStyle.

        Playback track buffered color

        :return: The playback_track_buffered_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._playback_track_buffered_color

    @playback_track_buffered_color.setter
    def playback_track_buffered_color(self, playback_track_buffered_color):
        # type: (string_types) -> None
        """Sets the playback_track_buffered_color of this StreamsStyleConfigPlayerStyle.

        Playback track buffered color

        :param playback_track_buffered_color: The playback_track_buffered_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if playback_track_buffered_color is not None:
            if not isinstance(playback_track_buffered_color, string_types):
                raise TypeError("Invalid type for `playback_track_buffered_color`, type has to be `string_types`")

        self._playback_track_buffered_color = playback_track_buffered_color

    @property
    def playback_track_bg_color(self):
        # type: () -> string_types
        """Gets the playback_track_bg_color of this StreamsStyleConfigPlayerStyle.

        Playback track background color

        :return: The playback_track_bg_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._playback_track_bg_color

    @playback_track_bg_color.setter
    def playback_track_bg_color(self, playback_track_bg_color):
        # type: (string_types) -> None
        """Sets the playback_track_bg_color of this StreamsStyleConfigPlayerStyle.

        Playback track background color

        :param playback_track_bg_color: The playback_track_bg_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if playback_track_bg_color is not None:
            if not isinstance(playback_track_bg_color, string_types):
                raise TypeError("Invalid type for `playback_track_bg_color`, type has to be `string_types`")

        self._playback_track_bg_color = playback_track_bg_color

    @property
    def text_color(self):
        # type: () -> string_types
        """Gets the text_color of this StreamsStyleConfigPlayerStyle.

        Text color

        :return: The text_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._text_color

    @text_color.setter
    def text_color(self, text_color):
        # type: (string_types) -> None
        """Sets the text_color of this StreamsStyleConfigPlayerStyle.

        Text color

        :param text_color: The text_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if text_color is not None:
            if not isinstance(text_color, string_types):
                raise TypeError("Invalid type for `text_color`, type has to be `string_types`")

        self._text_color = text_color

    @property
    def background_color(self):
        # type: () -> string_types
        """Gets the background_color of this StreamsStyleConfigPlayerStyle.

        Background color

        :return: The background_color of this StreamsStyleConfigPlayerStyle.
        :rtype: string_types
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        # type: (string_types) -> None
        """Sets the background_color of this StreamsStyleConfigPlayerStyle.

        Background color

        :param background_color: The background_color of this StreamsStyleConfigPlayerStyle.
        :type: string_types
        """

        if background_color is not None:
            if not isinstance(background_color, string_types):
                raise TypeError("Invalid type for `background_color`, type has to be `string_types`")

        self._background_color = background_color

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamsStyleConfigPlayerStyle):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
